@@ -4,8 +4,9 @@ from .document import Document
 from .document_image import DocumentImage
 from .static import Static, convert_umlaute_images, convert_umlaute_audio
 from .training_set import TrainingSet
-from . import group
 from .group_api_key import GroupAPIKey
+from .feedback import Feedback
+from . import group, content_type
 
 __all__ = [
     "AlternativeWord",
@@ -18,4 +19,5 @@ __all__ = [
     "convert_umlaute_audio",
     "group",
     "GroupAPIKey",
+    "Feedback",
 ]
